@@ -1,6 +1,6 @@
 
 from flask import request
-from notejob.center.app.core import db, scheduler
+from notejob.center.app import db, scheduler
 from notejob.center.app.crons import cron_do
 from notejob.center.app.decorated import api_deal_return, api_err_return
 from notejob.center.configs import configs
