@@ -7,7 +7,7 @@ import records
 import requests
 from flask import current_app
 from notejob.center.app.common.functions import single_task, wechat_info_err
-from notejob.center.app.core import db, scheduler
+from notejob.center.app import db, scheduler
 from notejob.center.configs import configs
 from notejob.center.datas.model.cron_infos import CronInfos
 from notejob.center.datas.model.job_log import JobLog
