@@ -1,10 +1,11 @@
-from . import main
+from.core import blue_print
 
-@main.app_errorhandler(404)
+
+@blue_print.app_errorhandler(404)
 def page_not_found(e):
     return 'page not found'
 
 
-@main.app_errorhandler(500)
+@blue_print.app_errorhandler(500)
 def internal_server_error(e):
     return 'system err'
