@@ -3,7 +3,7 @@ import traceback
 
 from flask import current_app, redirect, render_template, request, session
 from notejob.center.app.common.functions import web_api_return, wechat_info_err
-from notejob.center.app.core import db, scheduler
+from notejob.center.app import db, scheduler
 from notejob.center.app.crons import cron_do
 from notejob.center.app.decorated import login_required
 from notejob.center.datas.model import CronInfos, JobLog, JobLogItems
