@@ -1,5 +1,5 @@
 
-from notejob.center.app.core import db
+from notejob.center.app import db
 
 
 class JobLog(db.Model):
